import React, { ReactNode } from 'react';
import { ImageSourcePropType, StyleProp, ViewStyle, ImageStyle, TextStyle, ViewProps } from 'react-native';
import { IconSource } from '../__types__';
import { $DeepPartial } from '@callstack/react-theme-provider';
export declare type DrawerHeaderProps = ViewProps & {
    /**
     * The color used for the background
     *
     * Default: Theme.colors.primary
     */
    backgroundColor?: string;
    /**
     * An image to blend with the colored background in the header
     */
    backgroundImage?: ImageSourcePropType;
    /**
     * Opacity to use for blending the background image into the background color
     *
     * Default: 0.3
     */
    backgroundOpacity?: number;
    /** Color to use for header text elements */
    fontColor?: string;
    /** Icon to use to the left of the header text */
    icon?: IconSource;
    /** Callback to execute when the icon is pressed */
    onIconPress?: () => void;
    /** First line of text in the header */
    title?: string;
    /** Second line of text in the header */
    subtitle?: string;
    /** Custom content to use in place of the header title / subtitle */
    titleContent?: ReactNode;
    /** Style overrides for internal elements. The styles you provide will be combined with the default styles. */
    styles?: {
        root?: StyleProp<ViewStyle>;
        backgroundImageWrapper?: StyleProp<ViewStyle>;
        backgroundImage?: StyleProp<ImageStyle>;
        content?: StyleProp<ViewStyle>;
        textContent?: StyleProp<ViewStyle>;
        title?: StyleProp<TextStyle>;
        subtitle?: StyleProp<TextStyle>;
        icon?: StyleProp<ViewStyle>;
    };
    /**
     * Theme value overrides specific to this component.
     */
    theme?: $DeepPartial<ReactNativePaper.Theme>;
};
/**
 * [DrawerHeader](https://brightlayer-ui-components.github.io/react-native/?path=/info/components-documentation--drawer) component
 *
 * The DrawerHeader holds the content at the top of your navigation Drawer. You can supply a title and subtitle to
 * use the default styles, or you can supply your own custom titleContent to render. This section will always be pinned
 * at the top of the Drawer.
 */
export declare const DrawerHeader: React.FC<DrawerHeaderProps>;
