"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DrawerNavGroup = void 0;
const react_1 = __importStar(require("react"));
const typography_1 = require("../typography");
const react_native_1 = require("react-native");
const drawer_nav_item_1 = require("./drawer-nav-item");
const react_native_paper_1 = require("react-native-paper");
const utilities_1 = require("./utilities");
const drawer_context_1 = require("./context/drawer-context");
const context_1 = require("./context");
const react_native_safe_area_context_1 = require("react-native-safe-area-context");
const makeStyles = (props, theme, insets) => {
    const fontScale = react_native_1.PixelRatio.getFontScale();
    return react_native_1.StyleSheet.create({
        root: {},
        textContent: {
            height: 52 * fontScale,
            position: 'relative',
            justifyContent: 'center',
            paddingLeft: insets.left,
        },
        title: {
            paddingHorizontal: 16,
            color: props.titleColor || theme.colors.text,
        },
        divider: {
            position: 'absolute',
            left: 0,
            bottom: 0,
            right: 0,
        },
    });
};
/**
 * findID function
 *
 * A depth-first recursive search function to identify if the specified
 * id is anywhere in the tree of the supplied item.
 *
 * @param item The topmost item to start from
 * @param activeItem The id to search for
 * @returns true if the ID is found in the tree, false otherwise
 */
const findID = (item, activeItem) => {
    if (!activeItem)
        return false;
    // if leaf node, return
    if (!item.items && !item.children) {
        return item.itemID === activeItem;
    }
    // else, loop through the branches by items
    if (item.items) {
        for (let i = 0; i < item.items.length; i++) {
            if (findID(item.items[i], activeItem)) {
                return true;
            }
        }
    }
    // and by children
    if (item.children) {
        const childItems = utilities_1.findChildByType(item.children, ['DrawerNavItem']);
        for (let i = 0; i < childItems.length; i++) {
            if (findID(childItems[i].props, activeItem)) {
                return true;
            }
        }
    }
    // no active items found, return false
    return false;
};
/**
 * [DrawerNavGroup](https://brightlayer-ui-components.github.io/react-native/?path=/info/components-documentation--drawer) component
 *
 * The DrawerNavGroup represents a collection of navigation items to display in the Drawer, useful for organizing
 * your links into buckets. Each group can be given a `title` to describe its items. Individual items in each group can be passed
 * through the `items` prop or passed declaratively as children.
 */
exports.DrawerNavGroup = (props) => {
    const { 
    // Inheritable Props
    /* eslint-disable @typescript-eslint/no-unused-vars */
    activeItemBackgroundColor, activeItemBackgroundShape, activeItemFontColor, activeItemIconColor, backgroundColor, chevron, collapseIcon, disableActiveItemParentStyles, divider, expandIcon, hidePadding, itemFontColor, itemIconColor, nestedBackgroundColor, nestedDivider, theme: themeOverride, 
    /* eslint-enable @typescript-eslint/no-unused-vars */
    // DrawerNavGroup-specific props
    title, titleContent, titleColor /* eslint-disable-line @typescript-eslint/no-unused-vars */, items = [], styles = {}, 
    // Other View Props
    style, children, ...viewProps } = props;
    const theme = react_native_paper_1.useTheme(themeOverride);
    const insets = react_native_safe_area_context_1.useSafeAreaInsets();
    const defaultStyles = makeStyles(props, theme, insets);
    const { activeItem } = drawer_context_1.useDrawerContext();
    /* Keeps track of which group of IDs are in the 'active hierarchy' */
    const [activeHierarchyItems, setActiveHierarchyItems] = react_1.useState([]);
    /* Clear the active hierarchy array if the new active Item cannot be found in the tree */
    react_1.useEffect(() => {
        if (!findID({ items: props.items, children: props.children }, activeItem))
            setActiveHierarchyItems([]);
    }, [activeItem]);
    const getChildren = react_1.useCallback(() => utilities_1.findChildByType(children, ['DrawerNavItem'])
        // .slice(0, 1)
        .map((child) => react_1.default.cloneElement(child, {
        // Inherited Props
        ...utilities_1.inheritSharedProps(props, child.props),
        depth: 0,
        isInActiveTree: activeHierarchyItems.includes(child.props.itemID),
        notifyActiveParent: (ids) => {
            if (JSON.stringify(activeHierarchyItems) !== JSON.stringify(ids)) {
                // Sets the list of active IDs when we get a callback from an active child
                setActiveHierarchyItems(ids);
            }
        },
    })), [props, activeHierarchyItems, setActiveHierarchyItems, children]);
    return (react_1.default.createElement(context_1.NavGroupContext.Provider, { value: {
            activeHierarchy: activeHierarchyItems,
        } },
        react_1.default.createElement(react_native_1.View, Object.assign({ style: [defaultStyles.root, styles.root, style] }, viewProps),
            titleContent !== null && react_1.default.createElement(react_native_1.View, { style: { paddingLeft: insets.left } }, titleContent),
            !titleContent && title && (react_1.default.createElement(react_native_1.View, { style: [defaultStyles.textContent, styles.textContent] },
                react_1.default.createElement(typography_1.Overline, { style: [defaultStyles.title, styles.title] }, title),
                react_1.default.createElement(react_native_paper_1.Divider, { style: [defaultStyles.divider, styles.divider] }))),
            items.map((item, index) => (react_1.default.createElement(drawer_nav_item_1.DrawerNavItem, Object.assign({ key: `itemList_${index}` }, item, utilities_1.inheritSharedProps(props, item), { depth: 0, isInActiveTree: activeHierarchyItems.includes(item.itemID), notifyActiveParent: (ids) => {
                    if (JSON.stringify(activeHierarchyItems) !== JSON.stringify(ids)) {
                        // Sets the list of active IDs when we get a callback from an active child
                        setActiveHierarchyItems(ids);
                    }
                } })))),
            getChildren())));
};
exports.DrawerNavGroup.displayName = 'DrawerNavGroup';
