"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Header = void 0;
const react_1 = __importStar(require("react"));
const react_native_1 = require("react-native");
const color_1 = __importDefault(require("color"));
const react_native_paper_1 = require("react-native-paper");
const constants_1 = require("./constants");
const headerBackgroundImage_1 = require("./headerBackgroundImage");
const headerNavigationIcon_1 = require("./headerNavigationIcon");
const headerContent_1 = require("./headerContent");
const headerActionItems_1 = require("./headerActionItems");
const SearchContextProvider_1 = require("./contexts/SearchContextProvider");
const ColorContextProvider_1 = require("./contexts/ColorContextProvider");
const HeaderHeightContextProvider_1 = require("./contexts/HeaderHeightContextProvider");
var createAnimatedComponent = react_native_1.Animated.createAnimatedComponent;
const usePrevious_1 = require("../hooks/usePrevious");
const useHeaderDimensions_1 = require("../hooks/useHeaderDimensions");
const AnimatedSafeAreaView = createAnimatedComponent(react_native_1.SafeAreaView);
const headerStyles = (props, theme) => {
    const fontScale = react_native_1.PixelRatio.getFontScale();
    return react_native_1.StyleSheet.create({
        root: {
            width: '100%',
            backgroundColor: props.backgroundColor ||
                (theme.dark ? theme.colors.actionPalette?.active || theme.colors.surface : theme.colors.primary),
            shadowColor: 'rgba(0, 0, 0, 0.3)',
            shadowOffset: {
                width: 0,
                height: 1,
            },
            shadowRadius: 2,
            shadowOpacity: 1,
            elevation: 0,
        },
        content: {
            flex: 1,
            paddingVertical: 16 * fontScale,
            paddingHorizontal: 16,
            flexDirection: 'row',
            minHeight: 56 * fontScale,
        },
        search: {
            flex: 1,
            flexDirection: 'row',
            alignItems: 'center',
            paddingHorizontal: 16,
        },
    });
};
/**
 * [Header](https://brightlayer-ui-components.github.io/react-native/?path=/info/components-documentation--header) component
 *
 * The Header is used as the main banner at the top of application screens. It can display page information
 * via the `title`, `subtitle`, and `info` properties, as well as customizable backgrounds, colors, action items,
 * and more. The header can be configured to expand / collapse on press or on scroll (when using the [CollapsibleHeaderLayout](https://brightlayer-ui-components.github.io/react-native/?path=/info/components-documentation--collapsible-header-layout) component).
 */
exports.Header = (props) => {
    const { actionItems, backgroundColor, backgroundImage, expandable = false, expandedHeight: expandedHeightProp = 200, collapsedHeight: collapsedHeightProp = 56, fontColor, info, icon, onIconPress, scrollPosition = new react_native_1.Animated.Value(0), searchableConfig, startExpanded, subtitle, style, styles = {}, theme: themeOverride, title, variant = 'static', washingtonStyle, updateScrollView = () => { }, ...viewProps } = props;
    const { getScaledHeight, LANDSCAPE } = useHeaderDimensions_1.useHeaderDimensions();
    const theme = react_native_paper_1.useTheme(themeOverride);
    const defaultStyles = headerStyles(props, theme);
    const searchRef = react_1.useRef(null);
    // Utility variables
    const fontScale = react_native_1.PixelRatio.getFontScale();
    const collapsedHeight = getScaledHeight(collapsedHeightProp);
    const previousCollapsedHeight = usePrevious_1.usePrevious(collapsedHeight);
    const expandedHeight = getScaledHeight(expandedHeightProp);
    const previousExpandedHeight = usePrevious_1.usePrevious(expandedHeight);
    const scrollableDistance = expandedHeight - collapsedHeight;
    const previousScrollableDistance = usePrevious_1.usePrevious(scrollableDistance);
    const dynamicHeaderHeight = react_native_1.Animated.subtract(new react_native_1.Animated.Value(expandedHeight), scrollPosition);
    // Local State
    const [staticHeaderHeightValue, setStaticHeaderHeightValue] = react_1.useState(startExpanded ? expandedHeight : collapsedHeight);
    const [scrollPositionValue, setScrollPositionValue] = react_1.useState(0);
    const inDynamicRange = scrollPositionValue <= scrollableDistance;
    const [searching, setSearching] = react_1.useState(false);
    const expanded = staticHeaderHeightValue === expandedHeight;
    const [manuallyExpanded, setManuallyExpanded] = react_1.useState(false);
    const [previousExpanded, setPreviousExpanded] = react_1.useState(expanded);
    const [useStaticHeight, setUseStaticHeight] = react_1.useState(variant === 'static');
    const [query, setQuery] = react_1.useState('');
    const [staticHeaderHeight] = react_1.useState(startExpanded ? new react_native_1.Animated.Value(expandedHeight) : new react_native_1.Animated.Value(collapsedHeight));
    // Animation functions to smoothly transition the static Header height
    const expand = react_native_1.Animated.timing(staticHeaderHeight, {
        toValue: expandedHeight,
        duration: constants_1.ANIMATION_LENGTH,
        useNativeDriver: false,
    });
    const contract = react_native_1.Animated.timing(staticHeaderHeight, {
        toValue: collapsedHeight,
        duration: constants_1.ANIMATION_LENGTH,
        useNativeDriver: false,
    });
    /* UTILITY FUNCTIONS */
    // returns the count of each type of actionItem (component and icon) and the total width of components
    const getActionItemInfo = react_1.useCallback(() => {
        if (!actionItems)
            return { components: { count: 0, width: 0 }, icons: { count: 0 } };
        const actionComponents = actionItems.filter((item) => item.component);
        const componentsCount = actionComponents.length;
        const componentsWidth = actionComponents.reduce((accumulator, currentValue) => accumulator + (currentValue.width || 40 * fontScale), 0);
        return {
            components: { count: componentsCount, width: componentsWidth },
            icons: { count: actionItems.length - componentsCount },
        };
    }, [actionItems]);
    /* EVENT LISTENERS */
    // if variant is changed, make the necessary updates to sizing, margins, etc.
    react_1.useEffect(() => {
        // Going from dynamic -> static
        if (variant === 'static') {
            setUseStaticHeight(true);
            if (!inDynamicRange) {
                if (!expanded) {
                    updateScrollView({
                        padding: collapsedHeight,
                        animate: false,
                        scrollTo: scrollPositionValue - scrollableDistance,
                    });
                }
            }
            else {
                // less than halfway through the dynamic range -> use expanded
                if (scrollPositionValue <= scrollableDistance / 2) {
                    if (expanded) {
                        updateScrollView({ padding: expandedHeight, animate: false, scrollTo: 0 });
                    }
                }
                // more than halfway through the dynamic range -> use collapsed
                else if (!expanded) {
                    updateScrollView({ padding: collapsedHeight, animate: false, scrollTo: 0 });
                }
            }
        }
        // Going from static -> dynamic
        else {
            if (!inDynamicRange) {
                setUseStaticHeight(true);
                if (!expanded) {
                    updateScrollView({
                        padding: expandedHeight,
                        animate: false,
                        scrollTo: scrollPositionValue + scrollableDistance,
                    });
                }
            }
            else {
                setUseStaticHeight(false);
                if (expanded) {
                    staticHeaderHeight.setValue(scrollPositionValue <= scrollableDistance / 2 ? expandedHeight : collapsedHeight);
                    updateScrollView({
                        padding: expandedHeight,
                        animate: false,
                        scrollTo: scrollPositionValue <= scrollableDistance / 2 ? 0 : scrollableDistance,
                    });
                }
                else {
                    updateScrollView({
                        padding: expandedHeight,
                        animate: false,
                        scrollTo: scrollPositionValue <= scrollableDistance / 2 ? 0 : scrollableDistance,
                    });
                }
            }
        }
    }, [variant]);
    // if either height property is changed (or orientation), make the necessary updates to sizing, margins, etc.
    react_1.useEffect(() => {
        // don't execute this logic on the first render
        if (previousExpandedHeight === undefined || previousCollapsedHeight === undefined)
            return;
        const wasExpanded = staticHeaderHeightValue === previousExpandedHeight;
        staticHeaderHeight.setValue(wasExpanded ? expandedHeight : collapsedHeight);
        if (wasExpanded)
            expand.start();
        else
            contract.start();
        const scrollableDifference = scrollableDistance - (previousScrollableDistance || scrollableDistance);
        const expandedDifference = expandedHeight - (previousExpandedHeight || expandedHeight);
        const collapsedDifference = collapsedHeight - (previousCollapsedHeight || collapsedHeight);
        // was in the dynamic range
        if (scrollPositionValue <= (previousScrollableDistance || scrollableDistance)) {
            updateScrollView({
                padding: variant === 'dynamic' || wasExpanded ? expandedHeight : collapsedHeight,
                animate: false,
                scrollTo: variant === 'dynamic'
                    ? wasExpanded
                        ? -1 // workaround because if we pass 0 the ScrollView won't update because it thinks the scroll position is the same as before
                        : scrollableDistance
                    : scrollPositionValue + scrollableDifference,
            });
        }
        else {
            if (variant === 'static') {
                updateScrollView({
                    padding: wasExpanded ? expandedHeight : collapsedHeight,
                    animate: false,
                    scrollTo: scrollPositionValue + (wasExpanded ? expandedDifference : collapsedDifference),
                });
            }
            else {
                updateScrollView({
                    padding: expandedHeight,
                    animate: false,
                    scrollTo: scrollPositionValue + expandedDifference,
                });
            }
        }
    }, [expandedHeight, collapsedHeight, LANDSCAPE]);
    // Track the current value of the Animated header height
    const onHeightChange = react_1.useCallback(({ value: newHeight }) => {
        setStaticHeaderHeightValue(newHeight);
    }, []);
    // Make updates based on changes in the scroll position
    const onScrollChange = react_1.useCallback(({ value: scrollValue }) => {
        // save the current value of the animated scroll position
        setScrollPositionValue(scrollValue);
        if (variant !== 'dynamic' || searching)
            return;
        if (scrollValue <= scrollableDistance) {
            if (manuallyExpanded) {
                if (!useStaticHeight)
                    setUseStaticHeight(true);
                if (scrollValue <= 0) {
                    setUseStaticHeight(false);
                    setManuallyExpanded(false);
                }
            }
            else {
                setUseStaticHeight(false);
                // Adjust whether to collapse or expand on click based on how far the header is collapsed
                if (scrollValue <= scrollableDistance / 2) {
                    staticHeaderHeight.setValue(expandedHeight);
                }
                else {
                    staticHeaderHeight.setValue(collapsedHeight);
                }
            }
        }
        // We have scrolled out of the dynamic range (past the point of full collapse)
        else {
            if (!useStaticHeight && !manuallyExpanded) {
                staticHeaderHeight.setValue(collapsedHeight);
                setUseStaticHeight(true);
            }
        }
    }, [
        expandedHeight,
        collapsedHeight,
        scrollableDistance,
        useStaticHeight,
        staticHeaderHeight,
        variant,
        searching,
        manuallyExpanded,
    ]);
    // Set up listeners
    react_1.useEffect(() => {
        const statics = staticHeaderHeight.addListener(onHeightChange);
        const listen = scrollPosition.addListener(onScrollChange);
        return () => {
            scrollPosition.removeListener(listen);
            staticHeaderHeight.removeListener(statics);
        };
    }, [onScrollChange, onHeightChange]);
    /* STYLE FUNCTIONS */
    // Returns the clamped header height based on scroll position
    const getDynamicHeaderHeight = () => dynamicHeaderHeight.interpolate({
        inputRange: [collapsedHeight, expandedHeight],
        outputRange: [collapsedHeight, expandedHeight],
        extrapolate: 'clamp',
    });
    const getBackgroundColor = react_1.useCallback(() => {
        if (searching) {
            return theme.colors.surface;
        }
        return (backgroundColor ||
            (theme.dark ? theme.colors.actionPalette?.active || theme.colors.surface : theme.colors.primary));
    }, [searching, theme, backgroundColor]);
    const getFontColor = react_1.useCallback(() => {
        if (searching) {
            return theme.colors.text;
        }
        return fontColor || 'white';
    }, [theme, fontColor, searching]);
    const statusBarStyle = react_1.useCallback(() => color_1.default(getBackgroundColor()).isDark() ? 'light-content' : 'dark-content', [getBackgroundColor]);
    // Returns the interpolated bottom padding of the Header text elements
    const contentStyle = react_1.useCallback(() => {
        const contractedPadding = (subtitle && !searching ? 12 : 16) * fontScale;
        return [
            searching ? defaultStyles.search : defaultStyles.content,
            searching
                ? {}
                : {
                    paddingBottom: (useStaticHeight ? staticHeaderHeight : dynamicHeaderHeight).interpolate({
                        inputRange: [collapsedHeight, expandedHeight],
                        outputRange: [contractedPadding, 28],
                        extrapolate: 'clamp',
                    }),
                },
        ];
    }, [
        subtitle,
        searching,
        dynamicHeaderHeight,
        defaultStyles,
        useStaticHeight,
        staticHeaderHeight,
        collapsedHeight,
        expandedHeight,
    ]);
    /* CALLBACK FUNCTIONS */
    // Callback when the Header is tapped (expandable only)
    const onPress = react_1.useCallback(() => {
        if (expanded) {
            contract.start();
            setManuallyExpanded(false);
            updateScrollView({
                padding: variant === 'dynamic' ? expandedHeight : collapsedHeight,
                animate: inDynamicRange,
                scrollTo: variant === 'dynamic'
                    ? inDynamicRange
                        ? scrollableDistance
                        : null
                    : inDynamicRange
                        ? 0
                        : scrollPositionValue - scrollableDistance,
            });
        }
        else {
            expand.start();
            setManuallyExpanded(true);
            updateScrollView({
                padding: expandedHeight,
                animate: inDynamicRange,
                scrollTo: variant === 'dynamic'
                    ? inDynamicRange
                        ? 0
                        : null
                    : inDynamicRange
                        ? 0
                        : scrollPositionValue + scrollableDistance,
            });
        }
    }, [
        expanded,
        updateScrollView,
        collapsedHeight,
        contract,
        expand,
        expandedHeight,
        variant,
        inDynamicRange,
        scrollPositionValue,
        scrollableDistance,
    ]);
    // Callback when the search bar text is updated
    const onChangeSearchText = react_1.useCallback((text) => {
        setQuery(text);
        if (searchableConfig && searchableConfig.onChangeText)
            searchableConfig.onChangeText(text);
    }, [setQuery, searchableConfig]);
    // Callback when the search icon is clicked
    const onPressSearch = react_1.useCallback(() => {
        setUseStaticHeight(true);
        setSearching(true);
        contract.start(() => {
            // setSearching(true);
        });
        updateScrollView({
            padding: collapsedHeight,
            animate: expanded && inDynamicRange,
            scrollTo: variant === 'dynamic' || expanded ? Math.max(scrollPositionValue - scrollableDistance, 0) : null,
        });
        setPreviousExpanded(expanded);
    }, [
        contract,
        expandable,
        inDynamicRange,
        updateScrollView,
        variant,
        expanded,
        scrollPositionValue,
        scrollableDistance,
        collapsedHeight,
        staticHeaderHeightValue,
    ]);
    // Callback when the search bar content is cleared
    const onPressSearchClear = react_1.useCallback(() => {
        const searchInput = searchRef.current;
        if (searchInput) {
            searchInput.clear();
            if (searchableConfig && searchableConfig.onChangeText)
                searchableConfig.onChangeText('');
        }
        setQuery('');
    }, [searchableConfig, searchRef]);
    // Callback when the search bar is closed
    const onPressSearchClose = react_1.useCallback(() => {
        const searchInput = searchRef.current;
        if (searchInput) {
            if (searchableConfig && searchableConfig.onChangeText)
                searchableConfig.onChangeText('');
        }
        setSearching(false);
        setQuery('');
        if (previousExpanded) {
            expand.start();
            updateScrollView({
                padding: expandedHeight,
                animate: inDynamicRange,
                scrollTo: inDynamicRange ? 0 : scrollPositionValue + scrollableDistance,
            });
        }
        else {
            if (variant === 'dynamic') {
                updateScrollView({
                    padding: expandedHeight,
                    animate: false,
                    scrollTo: scrollPositionValue + scrollableDistance,
                });
            }
        }
    }, [
        searchableConfig,
        searchRef,
        previousExpanded,
        expand,
        expandedHeight,
        inDynamicRange,
        scrollPositionValue,
        scrollableDistance,
        updateScrollView,
        variant,
    ]);
    return (react_1.default.createElement(react_1.default.Fragment, null,
        react_1.default.createElement(react_native_1.StatusBar, { barStyle: statusBarStyle() }),
        react_1.default.createElement(react_native_1.TouchableWithoutFeedback, Object.assign({ onPress: () => onPress(), disabled: !expandable || searching }, viewProps),
            react_1.default.createElement(AnimatedSafeAreaView, { style: [
                    defaultStyles.root,
                    styles.root,
                    style,
                    /* We only use the dynamic height when we are in the dynamic range (from scrollPosition zero to expandedHeight - collapsedHeight)
                        Everywhere else, we use the fixed header height
                        */
                    { height: useStaticHeight ? staticHeaderHeight : getDynamicHeaderHeight() },
                    searching ? { backgroundColor: theme.colors.surface } : {},
                ] },
                react_1.default.createElement(SearchContextProvider_1.SearchContext.Provider, { value: {
                        searchRef: searchRef,
                        query: query,
                        searching: searching,
                        onQueryChange: onChangeSearchText,
                        searchConfig: searchableConfig,
                        onSearch: onPressSearch,
                        onClear: onPressSearchClear,
                        onClose: onPressSearchClose,
                    } },
                    react_1.default.createElement(ColorContextProvider_1.ColorContext.Provider, { value: { color: getFontColor() } },
                        react_1.default.createElement(HeaderHeightContextProvider_1.HeaderHeightContext.Provider, { value: {
                                headerHeight: useStaticHeight ? staticHeaderHeight : getDynamicHeaderHeight(),
                            } },
                            react_1.default.createElement(headerBackgroundImage_1.HeaderBackgroundImage, { backgroundImage: backgroundImage, style: styles.backgroundImage }),
                            react_1.default.createElement(react_native_1.Animated.View, { style: [contentStyle(), styles.content] },
                                react_1.default.createElement(headerNavigationIcon_1.HeaderNavigationIcon, { icon: icon, onPress: onIconPress, style: styles.icon }),
                                react_1.default.createElement(headerContent_1.HeaderContent, { theme: theme, title: title, subtitle: subtitle, info: info, actions: getActionItemInfo(), styles: {
                                        root: styles.textContent,
                                        title: styles.title,
                                        subtitle: styles.subtitle,
                                        info: styles.info,
                                        search: styles.search,
                                    }, washingtonStyle: washingtonStyle }),
                                react_1.default.createElement(headerActionItems_1.HeaderActionItems, { actionItems: actionItems, styles: {
                                        root: styles.actionPanel,
                                        actionItem: styles.actionItem,
                                        component: styles.component,
                                    } })))))))));
};
exports.Header.displayName = 'Header';
