"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.HeaderNavigationIcon = void 0;
const react_1 = __importDefault(require("react"));
const react_native_1 = require("react-native");
const constants_1 = require("./constants");
const MaterialIcons_1 = __importDefault(require("react-native-vector-icons/MaterialIcons"));
const headerIcon_1 = require("./headerIcon");
const SearchContextProvider_1 = require("./contexts/SearchContextProvider");
const ColorContextProvider_1 = require("./contexts/ColorContextProvider");
const makeStyles = () => {
    const fontScale = react_native_1.PixelRatio.getFontScale();
    return react_native_1.StyleSheet.create({
        navigation: {
            marginRight: 24,
            height: 40 * fontScale,
            width: 40 * fontScale,
            margin: -8 * fontScale,
            padding: 8 * fontScale,
        },
        flipIcon: {
            transform: [{ scaleX: -1 }],
        },
    });
};
/**
 * HeaderNavigationIcon component
 *
 * The HeaderNavigationIcon is a helper component that is used to properly size and space the main navigation icon (on the left) in the Header component.
 */
exports.HeaderNavigationIcon = (props) => {
    const { icon, onPress, style } = props;
    const { searching, onClose } = SearchContextProvider_1.useSearch();
    const { color } = ColorContextProvider_1.useColor();
    const defaultStyles = makeStyles();
    if (searching) {
        return (react_1.default.createElement(react_native_1.TouchableOpacity, { testID: 'header-search-close', onPress: onClose ? () => onClose() : undefined, style: [defaultStyles.navigation, style] },
            react_1.default.createElement(MaterialIcons_1.default, { name: 'arrow-back', size: constants_1.ICON_SIZE, color: color, allowFontScaling: true, style: react_native_1.I18nManager.isRTL ? defaultStyles.flipIcon : {} })));
    }
    if (icon) {
        return (react_1.default.createElement(react_native_1.TouchableOpacity, { testID: 'header-navigation', onPress: onPress, style: [defaultStyles.navigation, style], disabled: !onPress },
            react_1.default.createElement(headerIcon_1.HeaderIcon, { icon: icon })));
    }
    return null;
};
