"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.InfoListItem = void 0;
const react_1 = __importStar(require("react"));
const react_native_1 = require("react-native");
const MaterialCommunityIcons_1 = __importDefault(require("react-native-vector-icons/MaterialCommunityIcons"));
const react_native_paper_1 = require("react-native-paper");
const typography_1 = require("../typography");
const Colors = __importStar(require("@brightlayer-ui/colors"));
const color_1 = __importDefault(require("color"));
const utilities_1 = require("./utilities");
const icon_1 = require("../icon");
const getIconAlignment = (iconAlign) => {
    switch (iconAlign) {
        case 'right':
            return 'flex-end';
        case 'center':
            return 'center';
        case 'left':
        default:
            return 'flex-start';
    }
};
/**
 * Divider component
 *
 * A utility component for rendering a horizontal rule. This is a wrapper around the
 * react-native-paper Divider component that gives us the ability to do a partial or
 * full width divider.
 */
const Divider = (props) => {
    const { divider, style } = props;
    if (divider) {
        return (react_1.default.createElement(react_native_1.View, { style: {
                position: 'absolute',
                bottom: 0,
                right: 0,
                left: 0,
                alignItems: 'stretch',
            } },
            react_1.default.createElement(react_native_paper_1.Divider, { inset: divider === 'partial', style: style })));
    }
    return null;
};
const infoListItemStyles = (props, theme, fontScale) => react_native_1.StyleSheet.create({
    root: {
        backgroundColor: props.backgroundColor || 'transparent',
        minHeight: (props.dense ? 52 : 72) * fontScale,
        flexDirection: 'row',
        alignItems: 'center',
        paddingRight: 16,
    },
    title: {
        color: props.fontColor || theme.colors.text,
    },
    subtitleWrapper: {
        flexDirection: 'row',
        alignItems: 'center',
        overflow: 'hidden',
    },
    subtitle: {
        color: props.fontColor || theme.colors.text,
    },
    infoWrapper: {
        flexDirection: 'row',
        alignItems: 'center',
    },
    info: {
        color: props.fontColor || theme.colors.text,
    },
    statusStripe: {
        position: 'absolute',
        top: 0,
        left: 0,
        height: '100%',
        width: 6,
        backgroundColor: props.statusColor,
    },
    iconWrapper: {
        marginLeft: 16,
        width: 40 * fontScale,
        alignItems: 'flex-start',
        justifyContent: 'center',
    },
    avatar: {
        width: 40 * fontScale,
        height: 40 * fontScale,
        borderRadius: 20 * fontScale,
        alignItems: 'center',
        justifyContent: 'center',
        backgroundColor: props.statusColor || theme.colors.text,
    },
    icon: {
        width: 40 * fontScale,
        justifyContent: 'center',
        backgroundColor: 'transparent',
        alignItems: getIconAlignment(props.iconAlign),
    },
    mainContent: {
        flex: 1,
        paddingHorizontal: 16,
    },
    flipIcon: {
        transform: [{ scaleX: -1 }],
    },
});
/**
 * [InfoListItem](https://brightlayer-ui-components.github.io/react-native/?path=/info/components-documentation--info-list-item) component
 *
 * The InfoListItem is a component used to render lists. It extends the basic implementation
 * of a list item with additional features, such as icons and status stripes and supplies all of
 * the correct Brightlayer UI styles.
 */
exports.InfoListItem = (props) => {
    const { avatar, title, leftComponent, rightComponent, chevron, divider, subtitle, subtitleSeparator, info, statusColor, dense, //eslint-disable-line @typescript-eslint/no-unused-vars
    fontColor, //eslint-disable-line @typescript-eslint/no-unused-vars
    iconAlign, //eslint-disable-line @typescript-eslint/no-unused-vars
    iconColor, backgroundColor, //eslint-disable-line @typescript-eslint/no-unused-vars
    onPress, icon, hidePadding, styles = {}, theme: themeOverride, style, ...viewProps } = props;
    const theme = react_native_paper_1.useTheme(themeOverride);
    const fontScale = react_native_1.PixelRatio.getFontScale();
    const defaultStyles = infoListItemStyles(props, theme, fontScale);
    const getIconColor = react_1.useCallback(() => {
        if (iconColor)
            return iconColor;
        if (avatar) {
            return statusColor
                ? color_1.default(statusColor).isDark()
                    ? Colors.white[50]
                    : Colors.black[500]
                : Colors.white[50]; // default avatar is dark gray -> white text
        }
        return statusColor ? statusColor : theme.colors.textPalette?.secondary || theme.colors.text;
    }, [iconColor, avatar, statusColor, theme]);
    const getIcon = react_1.useCallback(() => {
        if (icon) {
            return (react_1.default.createElement(react_native_1.View, { style: avatar ? [defaultStyles.avatar, styles.avatar] : [defaultStyles.icon, styles.icon] },
                react_1.default.createElement(icon_1.Icon, { source: icon, size: 24, color: getIconColor() })));
        }
    }, [icon, avatar, getIconColor, defaultStyles, styles]);
    const getSubtitle = react_1.useCallback(() => {
        if (!subtitle) {
            return null;
        }
        const subtitleParts = Array.isArray(subtitle) ? [...subtitle] : [subtitle];
        const renderableSubtitleParts = subtitleParts.map((element) => utilities_1.renderableSubtitleComponent(element, Object.assign({}, defaultStyles.subtitle, styles.subtitle)));
        return utilities_1.withKeys(utilities_1.separate(renderableSubtitleParts, subtitleSeparator));
    }, [subtitle, subtitleSeparator, styles]);
    const getInfo = react_1.useCallback(() => {
        if (!info) {
            return null;
        }
        const infoParts = Array.isArray(info) ? [...info] : [info];
        const renderableInfoParts = infoParts.map((element) => utilities_1.renderableSubtitleComponent(element, Object.assign({}, defaultStyles.info, styles.info)));
        return utilities_1.withKeys(utilities_1.separate(renderableInfoParts, subtitleSeparator));
    }, [info, subtitleSeparator, styles]);
    const getRightComponent = react_1.useCallback(() => {
        if (rightComponent) {
            return rightComponent;
        }
        else if (chevron) {
            return (react_1.default.createElement(MaterialCommunityIcons_1.default, { name: "chevron-right", size: 24, color: theme.colors.text, allowFontScaling: true, style: react_native_1.I18nManager.isRTL ? defaultStyles.flipIcon : {} }));
        }
    }, [rightComponent, chevron, theme]);
    return (react_1.default.createElement(react_native_1.TouchableOpacity, Object.assign({ onPress: onPress, style: [defaultStyles.root, styles.root, style], disabled: !onPress, activeOpacity: 0.7 }, viewProps),
        react_1.default.createElement(react_native_1.View, { style: [defaultStyles.statusStripe, styles.statusStripe] }),
        icon || !hidePadding ? (react_1.default.createElement(react_native_1.View, { style: [defaultStyles.iconWrapper, styles.iconWrapper] }, getIcon())) : null,
        leftComponent,
        react_1.default.createElement(react_native_1.View, { style: [defaultStyles.mainContent, styles.mainContent] },
            react_1.default.createElement(typography_1.Subtitle1, { style: [defaultStyles.title, styles.title], numberOfLines: 1, ellipsizeMode: 'tail' }, title),
            react_1.default.createElement(react_native_1.View, { style: [defaultStyles.subtitleWrapper, styles.subtitleWrapper] }, getSubtitle()),
            react_1.default.createElement(react_native_1.View, { style: [defaultStyles.infoWrapper, styles.infoWrapper] }, getInfo())),
        getRightComponent(),
        react_1.default.createElement(Divider, { divider: divider, style: styles.divider })));
};
