"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.UserMenu = void 0;
const react_1 = __importStar(require("react"));
const react_native_1 = require("react-native");
const bottom_sheet_1 = require("./bottom-sheet");
const react_native_paper_1 = require("react-native-paper");
const info_list_item_1 = require("../info-list-item/info-list-item");
const react_native_safe_area_context_1 = require("react-native-safe-area-context");
const useStyles = (theme, fontScale, avatarSize) => react_native_1.StyleSheet.create({
    root: {
        backgroundColor: theme.colors.surface,
    },
    avatar: {
        width: avatarSize * fontScale,
        height: avatarSize * fontScale,
        borderRadius: avatarSize * fontScale,
    },
    bottomsheet: {},
});
/**
 * [UserMenu](https://brightlayer-ui-components.github.io/react-native/?path=/info/components-documentation--user-menu) component
 *
 * Renders an avatar that can be clicked to open a bottomsheet menu.
 *
 * Typically used for a account-style menu with links to settings, log out, etc.
 */
exports.UserMenu = (props) => {
    const theme = react_native_paper_1.useTheme(props.theme);
    const { avatar, backgroundColor, fontColor, iconColor = theme.colors.textPalette?.secondary || theme.colors.text, menuTitle, menuSubtitle, menuItems, styles = {}, } = props;
    const avatarSize = avatar.props.size || 40;
    const [showBottomSheet, setShowBottomSheet] = react_1.useState(false);
    const fontScale = react_native_1.PixelRatio.getFontScale();
    const defaultStyles = useStyles(theme, fontScale, avatarSize);
    const insets = react_native_safe_area_context_1.useSafeAreaInsets();
    const openMenu = () => {
        if (menuItems)
            setShowBottomSheet(true);
    };
    const closeMenu = () => {
        setShowBottomSheet(false);
    };
    const getAvatar = react_1.useCallback(() => react_1.default.cloneElement(avatar, {
        size: avatarSize * fontScale,
    }), [avatar]);
    const getMenu = react_1.useCallback(() => (react_1.default.createElement(react_1.default.Fragment, null,
        menuTitle && (react_1.default.createElement(react_1.default.Fragment, null,
            react_1.default.createElement(info_list_item_1.InfoListItem, { hidePadding: true, title: menuTitle || '', subtitle: menuSubtitle, leftComponent: react_1.default.createElement(react_native_1.View, { style: [defaultStyles.avatar, styles.avatar, { marginLeft: 16 }] }, getAvatar()), fontColor: fontColor, backgroundColor: backgroundColor }),
            react_1.default.createElement(react_native_paper_1.Divider, { style: { marginLeft: -1 * insets.left, marginRight: -1 * insets.right } }))),
        menuItems &&
            menuItems.map((menuItem, index) => {
                const menuItemStyles = menuItem.styles || {};
                return (react_1.default.createElement(info_list_item_1.InfoListItem, Object.assign({}, menuItem, { key: index, onPress: () => {
                        closeMenu();
                        if (menuItem.onPress)
                            menuItem.onPress();
                    }, iconColor: menuItem.iconColor || iconColor, fontColor: menuItem.fontColor || fontColor, backgroundColor: menuItem.backgroundColor || backgroundColor, dense: menuItem.dense !== undefined ? menuItem.dense : true, styles: Object.assign(menuItemStyles, {
                        title: Object.assign({
                            fontSize: 16,
                            fontFamily: theme.fonts.regular.fontFamily,
                            fontWeight: theme.fonts.regular.fontWeight,
                        }, menuItemStyles.title),
                        divider: Object.assign({
                            marginLeft: -1 * insets.left,
                            marginRight: -1 * insets.right,
                        }, menuItemStyles.divider),
                    }) })));
            }))), [menuItems, menuTitle, menuSubtitle, iconColor, fontColor, backgroundColor]);
    return (react_1.default.createElement(react_1.default.Fragment, null,
        react_1.default.createElement(react_native_1.TouchableWithoutFeedback, { onPress: () => openMenu(), testID: 'avatar', style: [defaultStyles.root, styles.root] }, getAvatar()),
        react_1.default.createElement(bottom_sheet_1.BottomSheet, { show: showBottomSheet, backgroundColor: backgroundColor, onClose: () => closeMenu(), styles: { root: styles.bottomsheet } }, getMenu())));
};
