"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ThemedAvatar = void 0;
const react_1 = __importDefault(require("react"));
const react_native_paper_1 = require("react-native-paper");
const ThemedIconAvatar = (props) => {
    const { theme: themeOverride, style: styleProp, color: colorProp, ...other } = props;
    const theme = react_native_paper_1.useTheme(themeOverride);
    const style = Object.assign(theme.dark
        ? {
            backgroundColor: theme.colors.overrides?.avatar?.background ||
                theme.colors.primaryPalette?.main ||
                theme.colors.primary,
        }
        : {
            backgroundColor: theme.colors.primaryPalette?.light || theme.colors.primary,
        }, styleProp);
    return (react_1.default.createElement(react_native_paper_1.Avatar.Icon, Object.assign({}, other, { style: style, color: colorProp ||
            (theme.dark ? theme.colors.textPalette?.primary : theme.colors.primaryPalette?.main) ||
            theme.colors.text, theme: themeOverride })));
};
const ThemedImageAvatar = (props) => {
    const { theme: themeOverride, style: styleProp, ...other } = props;
    const theme = react_native_paper_1.useTheme(themeOverride);
    const style = Object.assign(theme.dark
        ? {
            backgroundColor: theme.colors.overrides?.avatar?.background ||
                theme.colors.primaryPalette?.main ||
                theme.colors.primary,
        }
        : {
            backgroundColor: theme.colors.primaryPalette?.light || theme.colors.primary,
        }, styleProp);
    return react_1.default.createElement(react_native_paper_1.Avatar.Image, Object.assign({}, other, { style: style, theme: themeOverride }));
};
const ThemedTextAvatar = (props) => {
    const { theme: themeOverride, style: styleProp, color: colorProp, ...other } = props;
    const theme = react_native_paper_1.useTheme(themeOverride);
    const style = Object.assign(theme.dark
        ? {
            backgroundColor: theme.colors.overrides?.avatar?.background ||
                theme.colors.primaryPalette?.main ||
                theme.colors.primary,
        }
        : {
            backgroundColor: theme.colors.primaryPalette?.light || theme.colors.primary,
        }, styleProp);
    return (react_1.default.createElement(react_native_paper_1.Avatar.Text, Object.assign({}, other, { style: style, color: colorProp ||
            (theme.dark ? theme.colors.textPalette?.primary : theme.colors.primaryPalette?.main) ||
            theme.colors.primary, theme: themeOverride })));
};
/**
 * ThemedAvatar component
 *
 * This component is a wrapper around the React Native Paper [Avatar](https://callstack.github.io/react-native-paper/avatar-icon.html)
 * component. It accepts all the same props as the RNP component. The wrapper simply performs some minor theme / style overrides
 * in order to make the component look the way we want for Brightlayer UI projects.
 */
exports.ThemedAvatar = {
    Icon: ThemedIconAvatar,
    Image: ThemedImageAvatar,
    Text: ThemedTextAvatar,
};
