"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ThemedBadge = void 0;
const react_1 = __importDefault(require("react"));
const react_native_paper_1 = require("react-native-paper");
const useAlternateTheme_1 = require("./hooks/useAlternateTheme");
/**
 * ThemedBadge component
 *
 * This component is a wrapper around the React Native Paper [Badge](https://callstack.github.io/react-native-paper/badge.html)
 * component. It accepts all the same props as the RNP component. The wrapper simply performs some minor theme / style overrides
 * in order to make the component look the way we want for Brightlayer UI projects.
 */
exports.ThemedBadge = (props) => {
    const { theme: themeOverride, ...other } = props;
    const fullTheme = react_native_paper_1.useTheme(themeOverride);
    const theme = useAlternateTheme_1.useAlternateTheme(themeOverride, { colors: { notification: fullTheme.colors.primaryPalette?.main || fullTheme.colors.primary } }, { colors: { notification: fullTheme.colors.primaryPalette?.dark || fullTheme.colors.primary } });
    return react_1.default.createElement(react_native_paper_1.Badge, Object.assign({}, other, { theme: theme }));
};
