"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ThemedBottomNavigation = void 0;
const react_1 = __importDefault(require("react"));
const react_native_paper_1 = require("react-native-paper");
const useAlternateTheme_1 = require("./hooks/useAlternateTheme");
const color_1 = __importDefault(require("color"));
/**
 * ThemedBottomNavigation component
 *
 * This component is a wrapper around the React Native Paper [BottomNavigation](https://callstack.github.io/react-native-paper/bottom-navigation.html)
 * component. It accepts all the same props as the RNP component. The wrapper simply performs some minor theme / style overrides
 * in order to make the component look the way we want for Brightlayer UI projects.
 */
exports.ThemedBottomNavigation = (props) => {
    const { theme: themeOverride, ...other } = props;
    const defaultTheme = react_native_paper_1.useTheme(themeOverride);
    const theme = useAlternateTheme_1.useAlternateTheme(themeOverride, { colors: { notification: defaultTheme.colors.errorPalette?.main || defaultTheme.colors.error } }, { colors: { notification: defaultTheme.colors.errorPalette?.dark || defaultTheme.colors.error } });
    const fullTheme = react_native_paper_1.useTheme(theme);
    const activeColor = props.activeColor ||
        (fullTheme.dark ? fullTheme.colors.primaryPalette?.main : fullTheme.colors.textPalette?.onPrimary?.main) ||
        fullTheme.colors.text;
    const inactiveColor = props.inactiveColor ||
        fullTheme.colors.overrides?.bottomNavigation?.inactive ||
        (fullTheme.dark
            ? fullTheme.colors.textPalette?.onPrimary?.main
            : color_1.default(fullTheme.colors.textPalette?.onPrimary?.main).alpha(0.5).string()) ||
        fullTheme.colors.placeholder;
    return (react_1.default.createElement(react_native_paper_1.Provider, { theme: fullTheme },
        react_1.default.createElement(react_native_paper_1.BottomNavigation, Object.assign({}, other, { activeColor: activeColor, inactiveColor: inactiveColor, barStyle: Object.assign(fullTheme.dark
                ? { backgroundColor: fullTheme.colors.actionPalette?.background || fullTheme.colors.primary }
                : {}, props.barStyle), theme: theme }))));
};
