"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ThemedFAB = void 0;
const react_1 = __importDefault(require("react"));
const react_native_paper_1 = require("react-native-paper");
const useAlternateTheme_1 = require("./hooks/useAlternateTheme");
const ThemedFABComponent = (props) => {
    const { theme: themeOverride, ...other } = props;
    const fullTheme = react_native_paper_1.useTheme(themeOverride);
    const theme = useAlternateTheme_1.useAlternateTheme(themeOverride, { colors: { accent: fullTheme.colors.primaryPalette?.main || fullTheme.colors.primary } }, { colors: { accent: fullTheme.colors.primaryPalette?.dark || fullTheme.colors.primary } });
    return react_1.default.createElement(react_native_paper_1.FAB, Object.assign({}, other, { theme: theme }));
};
/**
 * ThemedFABGroup component
 *
 * This component is a wrapper around the React Native Paper [FAB.Group](https://callstack.github.io/react-native-paper/fab-group.html)
 * component. It accepts all the same props as the RNP component. The wrapper simply performs some minor theme / style overrides
 * in order to make the component look the way we want for Brightlayer UI projects.
 *
 * **NOTE**: Because the underlying FAB.Group component directly uses the FAB component from RNP (instead of our ThemedFAB component),
 * we have to wrap this component in an additional theme Provider. This works because both the FAB and FAB.Group use the same
 * alternate styles in their modified themes.
 */
const ThemedFABGroupComponent = (props) => {
    const { theme: themeOverride, ...other } = props;
    const defaultTheme = react_native_paper_1.useTheme(themeOverride);
    const theme = useAlternateTheme_1.useAlternateTheme(themeOverride, { colors: { accent: defaultTheme.colors.primaryPalette?.main || defaultTheme.colors.primary } }, { colors: { accent: defaultTheme.colors.primaryPalette?.dark || defaultTheme.colors.primary } });
    const fullTheme = react_native_paper_1.useTheme(theme);
    return (react_1.default.createElement(react_native_paper_1.Provider, { theme: fullTheme },
        react_1.default.createElement(react_native_paper_1.FAB.Group, Object.assign({}, other, { theme: theme }))));
};
/**
 * ThemedFAB component
 *
 * This component is a wrapper around the React Native Paper [FAB](https://callstack.github.io/react-native-paper/fab.html)
 * component. It accepts all the same props as the RNP component. The wrapper simply performs some minor theme / style overrides
 * in order to make the component look the way we want for Brightlayer UI projects.
 */
exports.ThemedFAB = Object.assign(ThemedFABComponent, {
    Group: ThemedFABGroupComponent,
});
