import React from 'react';
import { ViewStyle } from 'react-native';
import { ToggleButton } from 'react-native-paper';
export declare type ThemedToggleButtonProps = React.ComponentProps<typeof ToggleButton>;
export declare type ThemedToggleButtonRowProps = React.ComponentProps<typeof ToggleButton.Row>;
export declare type ThemedToggleButtonGroupProps = React.ComponentProps<typeof ToggleButton.Group>;
/**
 * ThemedToggleButton component
 *
 * This component is a wrapper around the React Native Paper [ToggleButton](https://callstack.github.io/react-native-paper/toggle-button.html)
 * component. It accepts all the same props as the RNP component. The wrapper simply performs some minor theme / style overrides
 * in order to make the component look the way we want for Brightlayer UI projects.
 */
export declare const ThemedToggleButton: React.FC<(Pick<{
    icon: import("react-native-paper/lib/typescript/components/Icon").IconSource;
    size?: number | undefined;
    color?: string | undefined;
    disabled?: boolean | undefined;
    accessibilityLabel?: string | undefined;
    onPress?: ((value?: string | import("react-native").GestureResponderEvent | undefined) => void) | undefined;
    value?: string | undefined;
    status?: "checked" | "unchecked" | undefined;
    style?: import("react-native").StyleProp<ViewStyle>;
    theme: ReactNativePaper.Theme;
}, "color" | "style" | "onPress" | "accessibilityLabel" | "disabled" | "size" | "value" | "icon" | "status"> & {
    theme?: import("@callstack/react-theme-provider").$DeepPartial<ReactNativePaper.Theme> | undefined;
}) | React.PropsWithChildren<Pick<{
    icon: import("react-native-paper/lib/typescript/components/Icon").IconSource;
    size?: number | undefined;
    color?: string | undefined;
    disabled?: boolean | undefined;
    accessibilityLabel?: string | undefined;
    onPress?: ((value?: string | import("react-native").GestureResponderEvent | undefined) => void) | undefined;
    value?: string | undefined;
    status?: "checked" | "unchecked" | undefined;
    style?: import("react-native").StyleProp<ViewStyle>;
    theme: ReactNativePaper.Theme;
}, "color" | "style" | "onPress" | "accessibilityLabel" | "disabled" | "size" | "value" | "icon" | "status"> & {
    theme?: import("@callstack/react-theme-provider").$DeepPartial<ReactNativePaper.Theme> | undefined;
}>> & {
    Group: {
        ({ value, onValueChange, children }: {
            onValueChange: (value: string) => void | null;
            value: string | null;
            children: React.ReactNode;
        }): JSX.Element;
        displayName: string;
    } | {
        ({ value, onValueChange, children }: {
            onValueChange: (value: string) => void | null;
            value: string | null;
            children: React.ReactNode;
        }): JSX.Element;
        displayName: string;
    };
    Row: React.FC<{
        onValueChange: (value: string) => void;
        value: string;
        children: React.ReactNode;
        style?: import("react-native").StyleProp<ViewStyle>;
    } | {
        onValueChange: (value: string) => void;
        value: string;
        children: React.ReactNode;
        style?: import("react-native").StyleProp<ViewStyle>;
    }>;
};
