"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ThemedToggleButton = void 0;
const react_1 = __importDefault(require("react"));
const react_native_1 = require("react-native");
const react_native_paper_1 = require("react-native-paper");
// @ts-ignore
const ToggleButtonGroup_1 = require("react-native-paper/lib/commonjs/components/ToggleButton/ToggleButtonGroup");
const color_1 = __importDefault(require("color"));
const useStyles = (theme) => react_native_1.StyleSheet.create({
    row: {
        flexDirection: 'row',
    },
    button: {
        borderWidth: 1,
        borderColor: theme.colors.disabled,
    },
    first: {
        borderTopRightRadius: 0,
        borderBottomRightRadius: 0,
    },
    middle: {
        borderRadius: 0,
        borderLeftWidth: 0,
    },
    last: {
        borderLeftWidth: 0,
        borderTopLeftRadius: 0,
        borderBottomLeftRadius: 0,
    },
});
/**
 * ThemedToggleButton component
 *
 * This component is a wrapper around the React Native Paper [ToggleButton](https://callstack.github.io/react-native-paper/toggle-button.html)
 * component. It accepts all the same props as the RNP component. The wrapper simply performs some minor theme / style overrides
 * in order to make the component look the way we want for Brightlayer UI projects.
 */
const ThemedToggleButtonComponent = (props) => {
    const { theme: themeOverride, style, color, ...other } = props;
    const fullTheme = react_native_paper_1.useTheme(themeOverride);
    return (react_1.default.createElement(ToggleButtonGroup_1.ToggleButtonGroupContext.Consumer, null, (context) => {
        const checked = (context && context.value === props.value) || props.status === 'checked';
        const backgroundColor = fullTheme.dark
            ? checked
                ? color_1.default(fullTheme.colors.primaryPalette?.dark || fullTheme.colors.primary)
                    .alpha(0.36)
                    .string()
                : fullTheme.colors.surface
            : checked
                ? fullTheme.colors.primaryPalette?.light || color_1.default(fullTheme.colors.primary).alpha(0.05).toString()
                : fullTheme.colors.surface;
        const textColor = fullTheme.dark
            ? checked
                ? fullTheme.colors.primaryPalette?.main || fullTheme.colors.primary
                : fullTheme.colors.placeholder
            : checked
                ? fullTheme.colors.primaryPalette?.main || fullTheme.colors.primary
                : fullTheme.colors.textPalette?.secondary || fullTheme.colors.text;
        return (react_1.default.createElement(react_native_paper_1.ToggleButton, Object.assign({}, other, { color: color || textColor, style: [{ backgroundColor: backgroundColor }, style], theme: themeOverride })));
    }));
};
/**
 * ThemedToggleButtonRow component
 *
 * This component is a wrapper around the React Native Paper [ToggleButton.Row](https://callstack.github.io/react-native-paper/toggle-button-row.html)
 * component. It accepts all the same props as the RNP component. The wrapper simply performs some minor theme / style overrides
 * in order to make the component look the way we want for Brightlayer UI projects.
 */
const ThemedToggleButtonRow = (props) => {
    const { children, ...other } = props;
    const count = react_1.default.Children.count(children);
    const fullTheme = react_native_paper_1.useTheme();
    const styles = useStyles(fullTheme);
    return (react_1.default.createElement(react_native_paper_1.ToggleButton.Row, Object.assign({}, other),
        react_1.default.createElement(ToggleButtonGroup_1.ToggleButtonGroupContext.Provider, { value: {
                value: props.value,
                onValueChange: props.onValueChange,
            } }, react_1.default.Children.map(children, (child, i) => {
            // @ts-expect-error: TypeScript complains about child.type but it doesn't matter
            if (child && child.type === ThemedToggleButtonComponent) {
                // @ts-expect-error: We're sure that child is a React Element
                return react_1.default.cloneElement(child, {
                    style: [
                        styles.button,
                        i === 0 ? styles.first : i === count - 1 ? styles.last : styles.middle,
                        // @ts-expect-error: We're sure that child is a React Element
                        child.props.style,
                    ],
                });
            }
            return child;
        }))));
};
/**
 * ThemedToggleButtonGroup component
 *
 * This component is a wrapper around the React Native Paper [ToggleButton.Group](https://callstack.github.io/react-native-paper/toggle-button-group.html)
 * component. It accepts all the same props as the RNP component. The wrapper simply performs some minor theme / style overrides
 * in order to make the component look the way we want for Brightlayer UI projects.
 */
const ThemedToggleButtonGroup = react_native_paper_1.ToggleButton.Group;
/**
 * ThemedToggleButton component
 *
 * This component is a wrapper around the React Native Paper [ToggleButton](https://callstack.github.io/react-native-paper/toggle-button.html)
 * component. It accepts all the same props as the RNP component. The wrapper simply performs some minor theme / style overrides
 * in order to make the component look the way we want for Brightlayer UI projects.
 */
exports.ThemedToggleButton = Object.assign(ThemedToggleButtonComponent, {
    Group: ThemedToggleButtonGroup,
    Row: ThemedToggleButtonRow,
});
